SuperLU: File List

SuperLU 7.0.1

File List
Here is a list of all files with brief descriptions:
[detail level 123]

DOC |
► EXAMPLE |
cfgmr.c | Flexible GMRES from ITSOL developed by Yousef Saad
citersol.c | Example #1 showing how to use ILU to precondition GMRES
citersol1.c | Example #2 showing how to use ILU to precondition GMRES
clinsol.c | LU factorization from CGSTRF (CGSSV)
clinsol1.c | LU factorization from CGSTRF (CGSSV)
clinsolx.c | LU factorization from CGSTRF (CGSSVX)
clinsolx1.c | CGSSVX to solve systems with the same matrix but different right-hand side
clinsolx2.c | CGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A
clinsolx3.c | @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A
dfgmr.c | Flexible GMRES from ITSOL developed by Yousef Saad
dgstrf.c | Computes an LU factorization of a general sparse matrix
ditersol.c | Example #1 showing how to use ILU to precondition GMRES
ditersol1.c | Example #2 showing how to use ILU to precondition GMRES
dlinsol.c | LU factorization from DGSTRF (DGSSV)
dlinsol1.c | LU factorization from DGSTRF (DGSSV)
dlinsolx.c | LU factorization from DGSTRF (DGSSVX)
dlinsolx1.c | DGSSVX to solve systems with the same matrix but different right-hand side
dlinsolx2.c | DGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A
dlinsolx3.c | @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A
dmemory.c | Memory details
dreadtriple_noheader.c | Read matrix in triplet format
sfgmr.c | Flexible GMRES from ITSOL developed by Yousef Saad
sitersol.c | Example #1 showing how to use ILU to precondition GMRES
sitersol1.c | Example #2 showing how to use ILU to precondition GMRES
slinsol.c | LU factorization from SGSTRF (SGSSV)
slinsol1.c | LU factorization from SGSTRF (SGSSV)
slinsolx.c | LU factorization from SGSTRF (SGSSVX)
slinsolx1.c | SGSSVX to solve systems with the same matrix but different right-hand side
slinsolx2.c | SGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A
slinsolx3.c | @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A
sp_ienv.c | Chooses machine-dependent parameters for the local environment
superlu.c | Small 5x5 example
zfgmr.c | Flexible GMRES from ITSOL developed by Yousef Saad
zitersol.c | Example #1 showing how to use ILU to precondition GMRES
zitersol1.c | Example #2 showing how to use ILU to precondition GMRES
zlinsol.c | LU factorization from ZGSTRF (ZGSSV)
zlinsol1.c | LU factorization from ZGSTRF (ZGSSV)
zlinsolx.c | LU factorization from ZGSTRF (ZGSSVX)
zlinsolx1.c | ZGSSVX to solve systems with the same matrix but different right-hand side
zlinsolx2.c | ZGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A
zlinsolx3.c | @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A
► FORTRAN |
c_fortran_cgssv.c |
c_fortran_dgssv.c |
c_fortran_sgssv.c |
c_fortran_zgssv.c |
f_main.F90 |
hbcode1.F90 |
test_omp.F |
z_f_main.F90 |
zhbcode1.F90 |
► SRC |
ccolumn_bmod.c | Performs numeric block updates
ccolumn_dfs.c | Performs a symbolic factorization
ccopy_to_ucol.c | Copy a computed column of U to the compressed data structure
cdiagonal.c | Auxiliary routines to work with diagonal elements
cgscon.c | Estimates reciprocal of the condition number of a general matrix
cgsequ.c | Computes row and column scalings
cgsisx.c | Computes an approximate solutions of linear equations A*X=B or A'*X=B
cgsitrf.c | Computes an ILU factorization of a general sparse matrix
cgsrfs.c | Improves computed solution to a system of inear equations
cgssv.c | Solves the system of linear equations A*X=B
cgssvx.c | Solves the system of linear equations A*X=B or A'*X=B
cgstrf.c | Computes an LU factorization of a general sparse matrix
cgstrs.c | Solves a system using LU factorization
clacon2.c | Estimates the 1-norm
clangs.c | Returns the value of the one norm
claqgs.c | Equlibrates a general sprase matrix
cldperm.c | Finds a row permutation so that the matrix has large entries on the diagonal
cmemory.c | Memory details
cmyblas2.c | Level 2 Blas operations
colamd.c | Approximate minimum degree column ordering algorithm
colamd.h |
cpanel_bmod.c | Performs numeric block updates
cpanel_dfs.c | Performs a symbolic factorization on a panel of symbols
cpivotgrowth.c | Computes the reciprocal pivot growth factor
cpivotL.c | Performs numerical pivoting
cpruneL.c | Prunes the L-structure
creadhb.c | Read a matrix stored in Harwell-Boeing format
creadMM.c | Read a matrix stored in Harwell-Boeing format. Contributed by Francois-Henry Rouet
creadrb.c | Read a matrix stored in Rutherford-Boeing format
creadtriple.c | Read a matrix stored in triplet (coordinate) format
csnode_bmod.c | Performs numeric block updates within the relaxed snode
csnode_dfs.c | Determines the union of row structures of columns within the relaxed node
csp_blas2.c | Sparse BLAS 2, using some dense BLAS 2 operations
csp_blas3.c | Sparse BLAS3, using some dense BLAS3 operations
cutil.c | Matrix utility functions
dcolumn_bmod.c | Performs numeric block updates
dcolumn_dfs.c | Performs a symbolic factorization
dcomplex.c | Common arithmetic for complex type
dcopy_to_ucol.c | Copy a computed column of U to the compressed data structure
ddiagonal.c | Auxiliary routines to work with diagonal elements
dGetDiagU.c | Extracts main diagonal of matrix
dgscon.c | Estimates reciprocal of the condition number of a general matrix
dgsequ.c | Computes row and column scalings
dgsisx.c | Computes an approximate solutions of linear equations A*X=B or A'*X=B
dgsitrf.c | Computes an ILU factorization of a general sparse matrix
dgsrfs.c | Improves computed solution to a system of inear equations
dgssv.c | Solves the system of linear equations A*X=B
dgssvx.c | Solves the system of linear equations A*X=B or A'*X=B
dgstrf.c | Computes an LU factorization of a general sparse matrix
dgstrs.c | Solves a system using LU factorization
dlacon2.c | Estimates the 1-norm
dlangs.c | Returns the value of the one norm
dlaqgs.c | Equlibrates a general sprase matrix
dldperm.c | Finds a row permutation so that the matrix has large entries on the diagonal
dmach.c |
dmemory.c | Memory details
dmyblas2.c | Level 2 Blas operations
dpanel_bmod.c | Performs numeric block updates
dpanel_dfs.c | Performs a symbolic factorization on a panel of symbols
dpivotgrowth.c | Computes the reciprocal pivot growth factor
dpivotL.c | Performs numerical pivoting
dpruneL.c | Prunes the L-structure
dreadhb.c | Read a matrix stored in Harwell-Boeing format
dreadMM.c | Read a matrix stored in Harwell-Boeing format. Contributed by Francois-Henry Rouet
dreadrb.c | Read a matrix stored in Rutherford-Boeing format
dreadtriple.c | Read a matrix stored in triplet (coordinate) format
dsnode_bmod.c | Performs numeric block updates within the relaxed snode
dsnode_dfs.c | Determines the union of row structures of columns within the relaxed node
dsp_blas2.c | Sparse BLAS 2, using some dense BLAS 2 operations
dsp_blas3.c | Sparse BLAS3, using some dense BLAS3 operations
dutil.c | Matrix utility functions
dzsum1.c | Takes sum of the absolute values of a complex vector and returns a double precision result
get_perm_c.c | Matrix permutation operations
heap_relax_snode.c | Identify the initial relaxed supernodes
icmax1.c | Finds the index of the element whose real part has maximum absolute value
ilu_ccolumn_dfs.c | Performs a symbolic factorization
ilu_ccopy_to_ucol.c | Copy a computed column of U to the compressed data structure and drop some small entries
ilu_cdrop_row.c | Drop small rows from L
ilu_cpanel_dfs.c | Performs a symbolic factorization on a panel of symbols and record the entries with maximum absolute value in each column
ilu_cpivotL.c | Performs numerical pivoting
ilu_csnode_dfs.c | Determines the union of row structures of columns within the relaxed node
ilu_dcolumn_dfs.c | Performs a symbolic factorization
ilu_dcopy_to_ucol.c | Copy a computed column of U to the compressed data structure and drop some small entries
ilu_ddrop_row.c | Drop small rows from L
ilu_dpanel_dfs.c | Performs a symbolic factorization on a panel of symbols and record the entries with maximum absolute value in each column
ilu_dpivotL.c | Performs numerical pivoting
ilu_dsnode_dfs.c | Determines the union of row structures of columns within the relaxed node
ilu_heap_relax_snode.c | Identify the initial relaxed supernodes
ilu_relax_snode.c | Identify initial relaxed supernodes
ilu_scolumn_dfs.c | Performs a symbolic factorization
ilu_scopy_to_ucol.c | Copy a computed column of U to the compressed data structure and drop some small entries
ilu_sdrop_row.c | Drop small rows from L
ilu_spanel_dfs.c | Performs a symbolic factorization on a panel of symbols and record the entries with maximum absolute value in each column
ilu_spivotL.c | Performs numerical pivoting
ilu_ssnode_dfs.c | Determines the union of row structures of columns within the relaxed node
ilu_zcolumn_dfs.c | Performs a symbolic factorization
ilu_zcopy_to_ucol.c | Copy a computed column of U to the compressed data structure and drop some small entries
ilu_zdrop_row.c | Drop small rows from L
ilu_zpanel_dfs.c | Performs a symbolic factorization on a panel of symbols and record the entries with maximum absolute value in each column
ilu_zpivotL.c | Performs numerical pivoting
ilu_zsnode_dfs.c | Determines the union of row structures of columns within the relaxed node
input_error.c | Error handler for input parameters
izmax1.c | Finds the index of the element whose real part has maximum absolute value
mainpage.h |
mark_relax.c | Record the rows pivoted by the relaxed supernodes
mc64ad.c |
memory.c | Precision-independent memory-related routines
mmd.c | Minimum degree algorithm
qselect.c | Quickselect: returns the k-th (zero-based) largest value in A[]
relax_snode.c | Identify initial relaxed supernodes
scolumn_bmod.c | Performs numeric block updates
scolumn_dfs.c | Performs a symbolic factorization
scomplex.c | Common arithmetic for complex type
scopy_to_ucol.c | Copy a computed column of U to the compressed data structure
scsum1.c | Takes sum of the absolute values of a complex vector and returns a single precision result
sdiagonal.c | Auxiliary routines to work with diagonal elements
sgscon.c | Estimates reciprocal of the condition number of a general matrix
sgsequ.c | Computes row and column scalings
sgsisx.c | Computes an approximate solutions of linear equations A*X=B or A'*X=B
sgsitrf.c | Computes an ILU factorization of a general sparse matrix
sgsrfs.c | Improves computed solution to a system of inear equations
sgssv.c | Solves the system of linear equations A*X=B
sgssvx.c | Solves the system of linear equations A*X=B or A'*X=B
sgstrf.c | Computes an LU factorization of a general sparse matrix
sgstrs.c | Solves a system using LU factorization
slacon2.c | Estimates the 1-norm
slangs.c | Returns the value of the one norm
slaqgs.c | Equlibrates a general sprase matrix
sldperm.c | Finds a row permutation so that the matrix has large entries on the diagonal
slu_cdefs.h | Header file for real operations
slu_Cnames.h | Macros defining how C routines will be called
slu_dcomplex.h | Header file for complex operations
slu_ddefs.h | Header file for real operations
slu_scomplex.h | Header file for complex operations
slu_sdefs.h | Header file for real operations
slu_util.h | Utility header file
slu_zdefs.h | Header file for real operations
smach.c |
smemory.c | Memory details
smyblas2.c | Level 2 Blas operations
sp_coletree.c | Tree layout and computation routines
sp_ienv.c | Chooses machine-dependent parameters for the local environment
sp_preorder.c | Permute and performs functions on columns of original matrix
spanel_bmod.c | Performs numeric block updates
spanel_dfs.c | Performs a symbolic factorization on a panel of symbols
spivotgrowth.c | Computes the reciprocal pivot growth factor
spivotL.c | Performs numerical pivoting
spruneL.c | Prunes the L-structure
sreadhb.c | Read a matrix stored in Harwell-Boeing format
sreadMM.c | Read a matrix stored in Harwell-Boeing format. Contributed by Francois-Henry Rouet
sreadrb.c | Read a matrix stored in Rutherford-Boeing format
sreadtriple.c | Read a matrix stored in triplet (coordinate) format
ssnode_bmod.c | Performs numeric block updates within the relaxed snode
ssnode_dfs.c | Determines the union of row structures of columns within the relaxed node
ssp_blas2.c | Sparse BLAS 2, using some dense BLAS 2 operations
ssp_blas3.c | Sparse BLAS3, using some dense BLAS3 operations
superlu_config.h |
superlu_enum_consts.h | Enum constants header file
superlu_timer.c | Timer functions to record the time used
supermatrix.h | Matrix type definitions
sutil.c | Matrix utility functions
util.c | Utility functions
zcolumn_bmod.c | Performs numeric block updates
zcolumn_dfs.c | Performs a symbolic factorization
zcopy_to_ucol.c | Copy a computed column of U to the compressed data structure
zdiagonal.c | Auxiliary routines to work with diagonal elements
zgscon.c | Estimates reciprocal of the condition number of a general matrix
zgsequ.c | Computes row and column scalings
zgsisx.c | Computes an approximate solutions of linear equations A*X=B or A'*X=B
zgsitrf.c | Computes an ILU factorization of a general sparse matrix
zgsrfs.c | Improves computed solution to a system of inear equations
zgssv.c | Solves the system of linear equations A*X=B
zgssvx.c | Solves the system of linear equations A*X=B or A'*X=B
zgstrf.c | Computes an LU factorization of a general sparse matrix
zgstrs.c | Solves a system using LU factorization
zlacon2.c | Estimates the 1-norm
zlangs.c | Returns the value of the one norm
zlaqgs.c | Equlibrates a general sprase matrix
zldperm.c | Finds a row permutation so that the matrix has large entries on the diagonal
zmemory.c | Memory details
zmyblas2.c | Level 2 Blas operations
zpanel_bmod.c | Performs numeric block updates
zpanel_dfs.c | Performs a symbolic factorization on a panel of symbols
zpivotgrowth.c | Computes the reciprocal pivot growth factor
zpivotL.c | Performs numerical pivoting
zpruneL.c | Prunes the L-structure
zreadhb.c | Read a matrix stored in Harwell-Boeing format
zreadMM.c | Read a matrix stored in Harwell-Boeing format. Contributed by Francois-Henry Rouet
zreadrb.c | Read a matrix stored in Rutherford-Boeing format
zreadtriple.c | Read a matrix stored in triplet (coordinate) format
zsnode_bmod.c | Performs numeric block updates within the relaxed snode
zsnode_dfs.c | Determines the union of row structures of columns within the relaxed node
zsp_blas2.c | Sparse BLAS 2, using some dense BLAS 2 operations
zsp_blas3.c | Sparse BLAS3, using some dense BLAS3 operations
zutil.c | Matrix utility functions
► TESTING |
► MATGEN |
cdotc.c |
clacgv.c |
clagge.c |
claghe.c |
clagsy.c |
clarge.c |
clarnd.c |
clarnv.c |
claror.c |
clarot.c |
clartg.c |
claset.c |
clatb4.c |
clatm2.c |
clatm3.c |
clatme.c |
clatms.c |
csymv.c |
dlabad.c |
dlagge.c |
dlagsy.c |
dlaran.c |
dlarge.c |
dlarnd.c |
dlarnv.c |
dlaror.c |
dlarot.c |
dlartg.c |
dlaruv.c |
dlaset.c |
dlatb4.c |
dlatm1.c |
dlatm2.c |
dlatm3.c |
dlatms.c |
matgen.h |
powi.c | Power with integer exponent
powi.h |
slabad.c |
slagge.c |
slagsy.c |
slaran.c |
slarge.c |
slarnd.c |
slarnv.c |
slaror.c |
slarot.c |
slartg.c |
slaruv.c |
slaset.c |
slatb4.c |
slatm1.c |
slatm2.c |
slatm3.c |
slatms.c |
zdotc.c |
zlacgv.c |
zlagge.c |
zlaghe.c |
zlagsy.c |
zlarge.c |
zlarnd.c |
zlarnv.c |
zlaror.c |
zlarot.c |
zlartg.c |
zlaset.c |
zlatb4.c |
zlatm2.c |
zlatm3.c |
zlatms.c |
zsymv.c |
cdrive.c |
cgst01.c |
cgst02.c |
cgst04.c |
cgst07.c |
ddrive.c |
dgst01.c |
dgst02.c |
dgst04.c |
dgst07.c |
sdrive.c |
sgst01.c |
sgst02.c |
sgst04.c |
sgst07.c |
sp_cconvert.c |
sp_dconvert.c |
sp_ienv.c |
sp_sconvert.c |
sp_zconvert.c |
zdrive.c |
zgst01.c |
zgst02.c |
zgst04.c |
zgst07.c |